@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-03 09:24:50
-@LastEditTime: 2021-09-17 17:51:43
+@LastEditTime: 2021-10-11 18:07:00
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -17,8 +17,6 @@ class SkuInfoHandler(ClientBaseHandler):
     :description: 获取SKU信息
     """
     @filter_check_params("num_iid")
-    @filter_check_head_sign()
-    @filter_check_params_sign()
     def get_async(self):
         """
         :description: 获取SKU信息
@@ -43,7 +41,7 @@ class SkuInfoHandler(ClientBaseHandler):
             if "items" in invoke_result_data.data["items_seller_list_get_response"].keys():
                 return self.response_json_success(invoke_result_data.data["items_seller_list_get_response"])
         else:
-            act_prize = ActPrizeModel(context=self).get_dict("goods_id=%s and sku_json<>'' and is_sku=1 ", params=[num_iid])
+            act_prize = ActPrizeModel(context=self).get_dict("goods_id=%s and sku_json<>'' and is_sku=1 ", field="sku_json", params=[num_iid])
             if not act_prize:
                 return self.response_json_error("error", "对不起，找不到该商品的sku")
             sku_detail = self.json_loads(act_prize['sku_json'])
@@ -54,8 +52,6 @@ class GoodsListHandler(ClientBaseHandler):
     """
     :description: 获取商品列表
     """
-    @filter_check_head_sign()
-    @filter_check_params_sign()
     def get_async(self):
         """
         :description: 获取商品列表
