@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-17 11:19:05
-@LastEditTime: 2021-11-17 15:28:07
+@LastEditTime: 2021-11-23 18:10:32
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -37,9 +37,11 @@ class TaskInfoListHandler(ClientBaseHandler):
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         daily_repeat_browse = invoke_result_data.data["daily_repeat_browse"] if invoke_result_data.data.__contains__("daily_repeat_browse") else False
-        task_list = task_base_model.get_client_task_list(app_id, act_id, module_id, user_id, task_types, app_key, app_secret, is_log, daily_repeat_browse)
+        result_list,task_info_list,task_count_list = task_base_model.get_client_task_list(app_id, act_id, module_id, user_id, task_types, app_key, app_secret, is_log, daily_repeat_browse)
         ref_params = {}
-        return self.response_json_success(self.business_process_executed(task_list, ref_params))
+        ref_params["task_info_list"] = task_info_list
+        ref_params["task_count_list"] = task_count_list
+        return self.response_json_success(self.business_process_executed(result_list, ref_params))
 
 
 
@@ -258,7 +260,7 @@ class InviteNewUserHandler(ClientBaseHandler):
         :param act_id:活动标识
         :param module_id:活动模块标识
         :param tb_user_id:用户标识
-        :param invite_user_id:邀请用户标识
+        :param invite_user_id:邀请人用户标识
         :param login_token:访问令牌
         :return: 
         :last_editors: HuangJianYi
@@ -268,7 +270,7 @@ class InviteNewUserHandler(ClientBaseHandler):
         user_id = self.get_user_id()
         module_id = int(self.get_param("module_id", 0))
         login_token = self.get_param("login_token")
-        invite_user_id = int(self.get_param("invite_user_id", 0))
+        from_user_id = int(self.get_param("invite_user_id", 0))
         task_base_model = TaskBaseModel(context=self)
 
         invoke_result_data = self.business_process_executing()
@@ -276,7 +278,7 @@ class InviteNewUserHandler(ClientBaseHandler):
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         check_user_nick = invoke_result_data.data["check_user_nick"] if invoke_result_data.data.__contains__("check_user_nick") else True
         continue_request_expire = invoke_result_data.data["continue_request_expire"] if invoke_result_data.data.__contains__("continue_request_expire") else 5
-        invoke_result_data = task_base_model.process_invite_new_user(app_id, act_id, module_id, user_id, login_token, invite_user_id, self.__class__.__name__, check_user_nick, continue_request_expire)
+        invoke_result_data = task_base_model.process_invite_new_user(app_id, act_id, module_id, user_id, login_token, from_user_id, self.__class__.__name__, check_user_nick, continue_request_expire)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         ref_params = {}
@@ -298,7 +300,7 @@ class InviteJoinMemberHandler(ClientBaseHandler):
         :param act_id:活动标识
         :param module_id:活动模块标识
         :param tb_user_id:用户标识
-        :param invite_user_id:邀请用户标识
+        :param invite_user_id:邀请人用户标识
         :param login_token:访问令牌
         :return: 
         :last_editors: HuangJianYi
@@ -308,7 +310,7 @@ class InviteJoinMemberHandler(ClientBaseHandler):
         user_id = self.get_user_id()
         module_id = int(self.get_param("module_id", 0))
         login_token = self.get_param("login_token")
-        invite_user_id = int(self.get_param("invite_user_id", 0))
+        from_user_id = int(self.get_param("invite_user_id", 0))
         task_base_model = TaskBaseModel(context=self)
 
         invoke_result_data = self.business_process_executing()
@@ -317,7 +319,7 @@ class InviteJoinMemberHandler(ClientBaseHandler):
         check_user_nick = invoke_result_data.data["check_user_nick"] if invoke_result_data.data.__contains__("check_user_nick") else True
         continue_request_expire = invoke_result_data.data["continue_request_expire"] if invoke_result_data.data.__contains__("continue_request_expire") else 5
         app_key, app_secret = self.get_app_key_secret()
-        invoke_result_data = task_base_model.process_invite_join_member(app_id, act_id, module_id, user_id, login_token, invite_user_id, self.__class__.__name__, self.get_param("access_token"), app_key, app_secret, check_user_nick, continue_request_expire)
+        invoke_result_data = task_base_model.process_invite_join_member(app_id, act_id, module_id, user_id, login_token, from_user_id, self.__class__.__name__, self.get_param("access_token"), app_key, app_secret, check_user_nick, continue_request_expire)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         ref_params = {}
