@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-26 18:31:06
-@LastEditTime: 2021-11-05 14:40:38
+@LastEditTime: 2021-11-17 15:32:52
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -49,7 +49,7 @@ class LoginHandler(ClientBaseHandler):
         if self.check_request_user(app_id, app_info_dict["current_limit_count"]):
             return self.response_json_error("current_limit", "登录失败")
 
-        invoke_result_data = self.business_process_executing(self.request_params)
+        invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
 
@@ -69,43 +69,31 @@ class LoginHandler(ClientBaseHandler):
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         invoke_result_data.data["user_nick"] = self.emoji_base64_to_emoji(invoke_result_data.data["user_nick"])
-        invoke_result_data = self.business_process_executed(invoke_result_data, app_id, act_id, module_id, open_id, user_nick, avatar)
+        ref_params = {}
+        ref_params["app_id"] = app_id
+        ref_params["act_id"] = act_id
+        ref_params["module_id"] = module_id
+        invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         return self.response_json_success(invoke_result_data.data)
 
-    def business_process_executing(self, request_params):
-        """
-        :description: 执行前事件
-        :param request_params: 请求参数字典
-        :return:
-        :last_editors: HuangJianYi
-        """
-        invoke_result_data = InvokeResultData()
-        invoke_result_data.data = {}
-        return invoke_result_data
-
-    def business_process_executed(self, invoke_result_data, app_id, act_id, module_id, open_id, user_nick, avatar):
+    def business_process_executed(self, result_data, ref_params):
         """
         :description: 执行后事件
-        :param invoke_result_data:框架处理结果
-        :param app_id：应用标识
-        :param act_id：活动标识
-        :param module_id：活动模块标识
-        :param open_id：open_id
-        :param user_nick：昵称
-        :param avatar：头像
+        :param result_data:result_data
+        :param ref_params: 关联参数
         :return:
         :last_editors: HuangJianYi
         """
-        user_info_dict = invoke_result_data.data
+        user_info_dict = result_data.data
         stat_base_model = StatBaseModel(context=self)
         key_list_dict = {}
         key_list_dict["VisitCountEveryDay"] = 1
         key_list_dict["VisitManCountEveryDay"] = 1
         key_list_dict["VisitManCountEveryDayIncrease"] = 1
-        stat_base_model.add_stat_list(app_id, act_id, module_id, user_info_dict["user_id"], open_id, key_list_dict)
-        return invoke_result_data
+        stat_base_model.add_stat_list(ref_params["app_id"], ref_params["act_id"], ref_params["module_id"], user_info_dict["user_id"], user_info_dict["open_id"], key_list_dict)
+        return result_data
 
 
 class UpdateUserInfoHandler(ClientBaseHandler):
