@@ -2,18 +2,11 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-15 11:30:45
-@LastEditTime: 2021-11-18 15:20:17
+@LastEditTime: 2021-11-29 16:41:33
 @LastEditors: HuangJianYi
-@Description: 
-"""
-# -*- coding: utf-8 -*-
-"""
-:Author: HuangJianYi
-:Date: 2020-05-12 20:11:48
-@LastEditTime: 2021-11-01 18:27:35
-@LastEditors: HuangJianYi
-:description: 
+@Description: 公共handler模块
 """
+
 import ast
 import random
 import decimal
