@@ -2,9 +2,9 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-03 10:43:58
-@LastEditTime: 2021-09-17 17:23:16
+@LastEditTime: 2021-11-29 16:38:45
 @LastEditors: HuangJianYi
-@Description: 
+@Description: 应用模块
 """
 from seven_cloudapp_frame.handlers.frame_base import *
 from seven_cloudapp_frame.models.top_base_model import *
@@ -128,7 +128,8 @@ class AppInfoHandler(ClientBaseHandler):
         :last_editors: HuangJianYi
         """
         app_base_model = AppBaseModel(context=self)
-        invoke_result_data = app_base_model.get_app_info_result(self.get_user_nick(), self.get_open_id(), self.get_param("access_token"))
+        app_key, app_secret = self.get_app_key_secret()
+        invoke_result_data = app_base_model.get_app_info_result(self.get_user_nick(), self.get_open_id(), self.get_param("access_token"), app_key, app_secret)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         return self.response_json_success(invoke_result_data.data)
