@@ -2,9 +2,9 @@
 """
 :Author: HuangJianYi
 :Date: 2021-08-03 10:11:39
-@LastEditTime: 2021-09-17 15:11:53
+@LastEditTime: 2021-11-29 16:38:58
 @LastEditors: HuangJianYi
-:description: 商品相关
+:description: 商品模块
 """
 from seven_cloudapp_frame.handlers.frame_base import *
 from seven_cloudapp_frame.models.top_base_model import *
@@ -161,7 +161,7 @@ class SpecialGoodsListHandler(ClientBaseHandler):
         page_index = int(self.get_param("page_index", 0))
         page_size = int(self.get_param("page_size", 20))
         goods_name = self.get_param("goods_name")
-        is_log = self.get_param("is_log",False)
+        is_log = bool(self.get_param("is_log",False))
         access_token = self.get_param("access_token")
 
         goods_base_model = GoodsBaseModel(context=self)
@@ -189,7 +189,7 @@ class BindSpecialGoodsHandler(ClientBaseHandler):
         access_token = self.get_param("access_token")
         goods_id = self.get_param("goods_id")
         goods_name = self.get_param("goods_name")
-        is_log = self.get_param("is_log",False)
+        is_log = bool(self.get_param("is_log", False))
 
         goods_base_model = GoodsBaseModel(context=self)
         app_key, app_secret = self.get_app_key_secret()
