@@ -2,9 +2,9 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-30 15:46:34
-@LastEditTime: 2021-10-13 09:36:08
+@LastEditTime: 2021-11-29 16:39:08
 @LastEditors: HuangJianYi
-@Description: 
+@Description: 投放模块
 """
 from seven_cloudapp_frame.handlers.frame_base import *
 from seven_cloudapp_frame.models.act_base_model import *
