@@ -2,9 +2,9 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-09 14:11:52
-@LastEditTime: 2021-11-19 09:30:46
+@LastEditTime: 2021-11-29 19:25:18
 @LastEditors: HuangJianYi
-@Description: 
+@Description: 订单模块
 """
 from seven_cloudapp_frame.models.enum import *
 from seven_cloudapp_frame.libs.customize.oss2_helper import *
@@ -87,12 +87,23 @@ class PrizeOrderListHandler(ClientBaseHandler):
         create_date_start = self.get_param("create_date_start")
         create_date_end = self.get_param("create_date_end")
         order_by = self.get_param("order_by","create_date desc")
-        is_search_roster = self.get_param("is_search_roster", False)
+        is_search_roster = self.get_param("is_search_roster", 0)
+        if is_search_roster == 0:
+            is_search_roster = False
+        else:
+            is_search_roster = True
         page_index = int(self.get_param("page_index", 0))
         page_size = int(self.get_param("page_size", 20))
 
+        invoke_result_data = self.business_process_executing()
+        if invoke_result_data.success == False:
+            return self.response_json_success({"data": []})
+
         order_base_model = OrderBaseModel(context=self)
-        return self.response_json_success(order_base_model.get_prize_order_list(app_id, act_id, user_id, user_open_id, nick_name, order_no, real_name, telephone, address, order_status, create_date_start, create_date_end, page_size, page_index, order_by, is_search_roster=is_search_roster, is_cache=False))
+        page_list, total = order_base_model.get_prize_order_list(app_id, act_id, user_id, user_open_id, nick_name, order_no, real_name, telephone, address, order_status, create_date_start, create_date_end, page_size, page_index, order_by, is_search_roster=is_search_roster, is_cache=False)
+        ref_params = {}
+        page_info = PageInfo(page_index, page_size, total, self.business_process_executed(page_list, ref_params))
+        return self.response_json_success(page_info)
 
 
 class PrizeRosterListHandler(ClientBaseHandler):
@@ -145,7 +156,9 @@ class PrizeRosterListHandler(ClientBaseHandler):
         params = []
         order_by ="create_date desc"
         invoke_result_data = self.business_process_executing()
-        if invoke_result_data.success == True:
+        if invoke_result_data.success == False:
+            return self.response_json_success({"data": []})
+        else:
             condition = invoke_result_data.data["condition"] if invoke_result_data.data.__contains__("condition") else ""
             params = invoke_result_data.data["params"] if invoke_result_data.data.__contains__("params") else []
             order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "create_date desc"
