@@ -2,9 +2,9 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-02 09:03:41
-@LastEditTime: 2021-10-13 09:43:45
+@LastEditTime: 2021-11-29 16:40:48
 @LastEditors: HuangJianYi
-@Description: 主题皮肤
+@Description: 主题皮肤模块
 """
 
 from seven_cloudapp_frame.handlers.frame_base import *
