@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-10-08 22:01:47
-@LastEditTime: 2021-10-15 14:26:05
+@LastEditTime: 2021-10-15 14:59:20
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -45,13 +45,14 @@ class CryptographyHelper:
         return plain_text
 
     @classmethod
-    def aes_encrypt(self, source, password, iv, mode=AES.MODE_CBC, encoding="utf-8"):
+    def aes_encrypt(self, source, password, iv, mode=AES.MODE_CBC, pad_char='\0', encoding="utf-8"):
         """
-        :Description: AES加密,CBC & ZeroPadding
+        :Description: AES加密,默认CBC & ZeroPadding
         :param source: 待加密字符串
         :param password: 密钥
         :param iv: 偏移量
         :param mode: AES加密模式
+        :param pad_char: 填充字符
         :param encoding: 编码
         :return: 加密后的字符串
         :last_editors: HuangJianYi
@@ -67,10 +68,10 @@ class CryptographyHelper:
         count = len(source)
         if count < length:
             add = (length - count)
-            source = source + ('\0' * add).encode(encoding)
+            source = source + (pad_char * add).encode(encoding)
         elif count > length:
             add = (length - (count % length))
-            source = source + ('\0' * add).encode(encoding)
+            source = source + (pad_char * add).encode(encoding)
         cipher_text = cryptor.encrypt(source)
         # 因为AES加密时候得到的字符串不一定是ascii字符集的，输出到终端或者保存时候可能存在问题
         # 所以这里统一把加密后的字符串转化为base64
@@ -79,7 +80,7 @@ class CryptographyHelper:
     @classmethod
     def aes_decrypt(self, source, password, iv, mode=AES.MODE_CBC, encoding="utf-8"):
         """
-        :Description: AES解密,CBC & ZeroPadding
+        :Description: AES解密,默认CBC
         :param source: 待解密字符串
         :param password: 密钥
         :param iv: 偏移量
