@@ -2,11 +2,11 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-19 09:23:14
-@LastEditTime: 2021-10-12 17:53:20
+@LastEditTime: 2021-11-11 09:45:04
 @LastEditors: HuangJianYi
 @Description: 
 """
-from time import strftime
+from time import *
 from requests_pkcs12 import post
 import requests
 from Crypto.Cipher import AES
@@ -57,22 +57,23 @@ class WeChatHelper:
 
         # 通过code获取access_token
         requset_url = 'https://api.weixin.qq.com/sns/jscode2session'
-        respone = None
+        response = None
         try:
-            respone = requests.get(requset_url, params=param)
-            respone_data = SevenHelper.json_loads(respone.text)
-            if respone_data.__contains__("errcode") and respone_data["errcode"] != 0:
+            response = requests.get(requset_url, params=param)
+            response_data = SevenHelper.json_loads(response.text)
+            if response_data.__contains__("errcode") and response_data["errcode"] != 0:
                 invoke_result_data.success = False
-                invoke_result_data.error_code = respone_data["errcode"]
-                invoke_result_data.error_message = respone_data["errmsg"]
+                invoke_result_data.error_code = response_data["errcode"]
+                invoke_result_data.error_message = response_data["errmsg"]
                 return invoke_result_data
-            open_id = respone_data['openid']
-            session_key = respone_data['session_key']
-            redis_init.set(redis_key, SevenHelper.json_dumps(respone_data), ex=60 * 60)
+            open_id = response_data['openid']
+            session_key = response_data['session_key']
+            redis_init.set(redis_key, SevenHelper.json_dumps(response_data), ex=60 * 60)
             redis_init.set(f"{app_id}_wechat_sessionkey:{open_id}", session_key, ex=60 * 60)
-            return respone_data
+            invoke_result_data.data = response_data
+            return invoke_result_data
         except Exception as ex:
-            self.logger_error.error("【code2_session】" + traceback.format_exc() + ":" + str(respone.text))
+            self.logger_error.error("【code2_session】" + traceback.format_exc())
             invoke_result_data.success = False
             invoke_result_data.error_code = "exception"
             invoke_result_data.error_message = traceback.format_exc()
@@ -110,7 +111,7 @@ class WeChatHelper:
             invoke_result_data.data = str(respone_data["access_token"])
             return invoke_result_data
         except Exception as ex:
-            self.logger_error.error("【get_access_token】" + traceback.format_exc() + ":" + str(respone.text))
+            self.logger_error.error("【get_access_token】" + traceback.format_exc())
             invoke_result_data.success = False
             invoke_result_data.error_code = "exception"
             invoke_result_data.error_message = traceback.format_exc()
@@ -244,7 +245,7 @@ class WeChatHelper:
 
 class WeChatPayRequest(object):
     """
-    :description: 微信支付请求类,配置文件内容 "wechat_pay": {"api_key": "","mch_id": "","certificate_url":"","pay_notify_url":""}
+    :description: 微信支付请求类,配置文件内容 "wechat_pay": {"api_key": "","mch_id": "","certificate_url":""}
     """
     """配置账号信息"""
     # =======【基本信息设置】=====================================
@@ -308,7 +309,7 @@ class WeChatPayRequest(object):
         :description: 创建微信预订单
         :param pay_order_no：商户订单号(支付单号)
         :param body：订单描述
-        :param total_fee：支付金额
+        :param total_fee：支付金额；单位元
         :param spbill_create_ip：客户端IP
         :param notify_url：微信支付结果异步通知地址
         :param open_id：微信open_id
@@ -458,7 +459,7 @@ class WeChatPayRequest(object):
         :param pay_order_no:商户分配订单号，标识进行退款的订单，开发者服务端的唯一订单号
         :param notify_url:退款通知地址
         :param refund_fee: 退款金额，单位[分]
-        :param total_fee：支付金额
+        :param total_fee：支付金额；单位元
         :return: 
         :last_editors: HuangJianYi
         """
