@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-28 09:54:51
-@LastEditTime: 2021-09-26 12:20:12
+@LastEditTime: 2021-11-25 10:59:56
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -69,20 +69,24 @@ class AppBaseModel():
             invoke_result_data.error_message = "小程序不存在"
             return invoke_result_data
         result = {}
+        app_info_dict["expiration_date"] = str(app_info_dict["expiration_date"])
         if app_info_dict["expiration_date"] == "1900-01-01 00:00:00":
             result["is_expire"] = 0
-        elif TimeHelper.format_time_to_datetime(now_date) > TimeHelper.format_time_to_datetime(app_info_dict["expiration_date"]):
+        elif now_date > app_info_dict["expiration_date"]:
             result["is_expire"] = 1
         else:
             result["is_expire"] = 0
         invoke_result_data.data = result
         return invoke_result_data
 
-    def get_left_navigation(self,user_nick,access_token):
+    def get_left_navigation(self, user_nick, access_token, app_key, app_secret, app_id=""):
         """
         :description: 获取左侧导航
         :param user_nick: 用户昵称
+        :param app_key: app_key
+        :param app_secret: app_secret
         :param access_token: access_token
+        :param app_id: 应用标识
         :return
         :last_editors: HuangJianYi
         """
@@ -100,17 +104,16 @@ class AppBaseModel():
             invoke_result_data.error_message = "基础信息不存在"
             return invoke_result_data
         
-        app_info = None
-        app_id = self.get_param("app_id")
+        app_info_dict = None
         if app_id:
-            app_info = AppInfoModel(context=self).get_entity("app_id=%s", params=app_id)
+            app_info_dict = self.get_app_info_dict(app_id)
 
         # 左上角信息
         info = {}
         info["company"] = "天志互联"
         info["miniappName"] = base_info_dict["product_name"]
         info["logo"] = base_info_dict["product_icon"]
-        info["client_now_ver"] = app_info.template_ver if app_info else ""
+        info["client_now_ver"] = app_info_dict["template_ver"] if app_info_dict else ""
 
         # 左边底部菜单
         helper_info = {}
@@ -124,12 +127,12 @@ class AppBaseModel():
         renew_info = {}
         renew_info["surplus_day"] = 0
         dead_date = ""
-        if app_info:
-            helper_info["phone"] = app_info.app_telephone
-            dead_date = app_info.expiration_date
+        if app_info_dict:
+            helper_info["phone"] = app_info_dict["app_telephone"]
+            dead_date = app_info_dict["expiration_date"]
         else:
             top_base_model = TopBaseModel(context=self.context)
-            invoke_result_data = top_base_model.get_dead_date(store_user_nick,access_token)
+            invoke_result_data = top_base_model.get_dead_date(store_user_nick,access_token, app_key, app_secret)
             if invoke_result_data.success == False:
                 return invoke_result_data
             dead_date = invoke_result_data.data
@@ -167,12 +170,14 @@ class AppBaseModel():
         invoke_result_data.data =data
         return invoke_result_data
    
-    def get_app_info_result(self,user_nick,open_id,access_token):
+    def get_app_info_result(self, user_nick, open_id, access_token, app_key, app_secret):
         """
         :description: 获取小程序信息
         :param user_nick:用户昵称
         :param open_id:open_id
         :param access_token:access_token
+        :param app_secret: app_secret
+        :param access_token: access_token
         :return app_info
         :last_editors: HuangJianYi
         """
@@ -192,7 +197,7 @@ class AppBaseModel():
         app_info_model = AppInfoModel(context=self.context)
         app_info = app_info_model.get_entity("store_user_nick=%s", params=store_user_nick)
         top_base_model = TopBaseModel(context=self.context)
-        invoke_result_data = top_base_model.get_dead_date(store_user_nick,access_token)
+        invoke_result_data = top_base_model.get_dead_date(store_user_nick, access_token, app_key, app_secret)
         if invoke_result_data.success == False:
             return invoke_result_data
         dead_date = invoke_result_data.data
@@ -203,7 +208,8 @@ class AppBaseModel():
             if dead_date != "expire":
                 app_info.expiration_date = dead_date
             app_info_model.update_entity(app_info,"expiration_date,access_token")
-
+            app_info_model.delete_dependency_key(f"app_info:appid_{app_info.app_id}")
+            
             app_info.user_nick = user_nick
             app_info.dead_date = dead_date
             if app_info.dead_date != "expire":
@@ -215,7 +221,7 @@ class AppBaseModel():
         else:
             app_info = AppInfo()
             app_info.access_token = access_token
-            base_info = BaseInfoModel(context=self.context).get_dict()
+            base_info = BaseInfoModel(context=self.context).get_dict(field="client_ver")
             
             app_info.template_ver = base_info["client_ver"]
             app_info.user_nick = user_nick
