@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-05-12 20:11:48
-@LastEditTime: 2021-10-13 17:13:18
+@LastEditTime: 2021-11-23 14:15:22
 @LastEditors: HuangJianYi
 :description: 
 """
@@ -233,7 +233,7 @@ class AssetBaseModel():
             asset_log.open_id = open_id
             asset_log.user_nick = user_nick
             asset_log.log_title = log_title
-            asset_log.info_json = info_json if not info_json else {}
+            asset_log.info_json = info_json if info_json else {}
             asset_log.asset_type = asset_type
             asset_log.asset_object_id = asset_object_id
             asset_log.source_type = source_type
