@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-19 13:37:16
-@LastEditTime: 2021-10-29 13:42:20
+@LastEditTime: 2021-11-25 11:55:07
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -132,7 +132,7 @@ class StatConsoleModel():
                             stat_queue_model.update_entity(stat_queue, "process_count,process_result,process_date")
                             continue
                 else:
-                    time.sleep(int(config.get_value("stat_sleep_time", 1)))
+                    time.sleep(1)
             except Exception as ex:
                 logger_error.error(f"统计队列{mod_value}异常,ex:{traceback.format_exc()}")
                 time.sleep(5)
