@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-27 10:55:09
-@LastEditTime: 2021-10-19 18:25:27
+@LastEditTime: 2021-11-24 13:37:38
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -47,6 +47,7 @@ class PrizeOrder:
         self.order_status = 0  # 订单状态（-1未付款-2付款中0未发货1已发货2不予发货3已退款4交易成功）
         self.buyer_remark = ""  # 买家备注
         self.seller_remark = ""  # 卖家备注
+        self.order_price = 0  # 订单金额
         self.is_free_freight = 0  # 是否包邮
         self.freight_price = 0  # 运费金额
         self.freight_pay_order_no = ""  # 运费支付单号
@@ -72,7 +73,7 @@ class PrizeOrder:
 
     @classmethod
     def get_field_list(self):
-        return ['id', 'order_no', 'app_id', 'act_id', 'module_id', 'user_id', 'open_id', 'user_nick', 'real_name', 'telephone', 'province', 'city', 'county', 'street', 'address', 'deliver_date', 'express_no', 'express_company', 'order_status', 'buyer_remark', 'seller_remark', 'is_free_freight', 'freight_price', 'freight_pay_order_no', 'create_date', 'create_month', 'create_day', 'sync_status', 'sync_date', 'sync_count', 'sync_result', 'i1', 'i2', 'i3', 'i4', 'i5', 's1', 's2', 's3', 's4', 's5', 'd1','d2']
+        return ['id', 'order_no', 'app_id', 'act_id', 'module_id', 'user_id', 'open_id', 'user_nick', 'real_name', 'telephone', 'province', 'city', 'county', 'street', 'address', 'deliver_date', 'express_no', 'express_company', 'order_status', 'buyer_remark', 'seller_remark', 'order_price', 'is_free_freight', 'freight_price', 'freight_pay_order_no', 'create_date', 'create_month', 'create_day', 'sync_status', 'sync_date', 'sync_count', 'sync_result', 'i1', 'i2', 'i3', 'i4', 'i5', 's1','s2', 's3', 's4', 's5', 'd1', 'd2']
 
     @classmethod
     def get_primary_key(self):
