@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-02 09:44:36
-@LastEditTime: 2021-08-26 11:00:44
+@LastEditTime: 2021-09-17 20:05:33
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -49,7 +49,7 @@ class IpBaseModel():
         :last_editors: HuangJianYi
         """
         invoke_result_data = InvokeResultData()
-        if not app_id or not act_id or not ip_name:
+        if not act_id or not ip_name:
             invoke_result_data.success = False
             invoke_result_data.error_code = "param_error"
             invoke_result_data.error_message = "参数不能为空或等于0"
