@@ -9,12 +9,12 @@ from seven_cloudapp_frame.models.db_models.price.price_gear_model import *
 
 class LaunchBaseModel():
     """
-    :description: 投放基类
+    :description: 淘宝商品投放业务模型
     """
     def __init__(self, context):
         self.context = context
 
-    def add_launch_goods(self, app_id, act_id, goods_id, old_goods_id,source_types):
+    def add_launch_goods(self, app_id, act_id, goods_id, old_goods_id, source_types):
         """
         :description: 添加商品投放
         :param app_id：应用标识
@@ -169,7 +169,7 @@ class LaunchBaseModel():
         invoke_result_data.data = result_data
         return invoke_result_data
 
-    def async_launch_goods(self, app_id, act_id, online_url,access_token,app_key, app_secret,is_log=False):
+    def async_launch_goods(self, app_id, act_id, online_url, access_token, app_key, app_secret, is_log=False):
         """
         :description: 同步投放商品（小程序投放-商品绑定/解绑）
         :param app_id：应用标识
@@ -221,7 +221,7 @@ class LaunchBaseModel():
                 if len(no_launch_goods) > 0:
                     if async_result_info["success"] == True:
                         no_launch_goods[0].is_sync = 1
-                        no_launch_goods[0].sync_date = self.get_now_datetime()
+                        no_launch_goods[0].sync_date = SevenHelper.get_now_datetime()
                     else:
                         no_launch_goods[0].error_message = async_result_info["fail_msg"]
                     update_no_launch_goods_list.append(no_launch_goods[0])
@@ -254,7 +254,7 @@ class LaunchBaseModel():
                 if len(launch_goods) > 0:
                     if async_result_info["success"] == True:
                         launch_goods[0].is_sync = 1
-                        launch_goods[0].sync_date = self.get_now_datetime()
+                        launch_goods[0].sync_date = SevenHelper.get_now_datetime()
                     else:
                         launch_goods[0].is_launch = 0
                         launch_goods[0].is_sync = 1
@@ -265,7 +265,7 @@ class LaunchBaseModel():
         
         return invoke_result_data
 
-    def launch_goods_list(self,app_id,act_id,page_size,page_index,access_token,app_key, app_secret):
+    def get_launch_goods_list(self, app_id, act_id, page_size, page_index, access_token, app_key, app_secret):
         """
         :description: 获取投放商品列表
         :param app_id:应用标识
