@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-09 09:24:43
-@LastEditTime: 2021-10-29 13:42:52
+@LastEditTime: 2021-11-29 19:09:14
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -371,7 +371,7 @@ class OrderBaseModel(FrameBaseModel):
                     return invoke_result_data
                     
         #获取用户信息
-        user_info_dict = user_info_model.get_dict_by_id("act_id=%s and user_id=%s", params=[act_id, user_id])
+        user_info_dict = user_info_model.get_dict("act_id=%s and user_id=%s", params=[act_id, user_id])
         if not user_info_dict:
             invoke_result_data.success = False
             invoke_result_data.error_code = "error"
