@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-26 15:44:04
-@LastEditTime: 2021-09-07 09:35:03
+@LastEditTime: 2021-11-25 10:38:34
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -144,7 +144,7 @@ class ThemeBaseModel():
             ActModuleModel(context=self.context).update_table("skin_id=%s", "act_id=%s", [skin_info.id, act_id])
         return invoke_result_data
         
-    def save_theme(self, app_id, theme_name, client_json, server_json, out_id, ver_no):
+    def save_theme(self, app_id, theme_name, client_json, server_json, out_id, ver_no, style_type):
         """
         :description: 添加或修改主题
         :param app_id：app_id
@@ -153,11 +153,12 @@ class ThemeBaseModel():
         :param server_json：服务端内容json
         :param out_id：外部id
         :param ver_no：客户端版本号
+        :param style_type：样式类型
         :return: 
         :last_editors: HuangJianYi
         """
         invoke_result_data = InvokeResultData()
-        if not out_id:
+        if not out_id or not ver_no:
             invoke_result_data.success = False
             invoke_result_data.error_code = "param_error"
             invoke_result_data.error_message = "参数不能为空或等于0"
@@ -168,21 +169,18 @@ class ThemeBaseModel():
         theme_info = theme_info_model.get_entity("out_id=%s", params=[out_id])
         if theme_info:
             if client_json:
-                if ver_no:
-                    theme_ver = theme_ver_model.get_entity('out_id=%s and ver_no=%s', params=[out_id, ver_no])
-                    if theme_ver:
-                        theme_ver_model.update_table('client_json=%s', 'out_id=%s and ver_no=%s', params=[client_json, out_id, ver_no])
-                    else:
-                        theme_ver = ThemeVer()
-                        theme_ver.app_id = theme_info.app_id
-                        theme_ver.out_id = out_id
-                        theme_ver.theme_id = theme_info.id
-                        theme_ver.client_json = client_json
-                        theme_ver.ver_no = ver_no
-                        theme_ver.create_date = theme_info.create_date
-                        theme_ver_model.add_entity(theme_ver)
+                theme_ver = theme_ver_model.get_entity('out_id=%s and ver_no=%s', params=[out_id, ver_no])
+                if theme_ver:
+                    theme_ver_model.update_table('client_json=%s', 'out_id=%s and ver_no=%s', params=[client_json, out_id, ver_no])
                 else:
-                    theme_info_model.update_table('client_json=%s', 'out_id=%s', params=[client_json, out_id])
+                    theme_ver = ThemeVer()
+                    theme_ver.app_id = theme_info.app_id
+                    theme_ver.out_id = out_id
+                    theme_ver.theme_id = theme_info.id
+                    theme_ver.client_json = client_json
+                    theme_ver.ver_no = ver_no
+                    theme_ver.create_date = theme_info.create_date
+                    theme_ver_model.add_entity(theme_ver)
             if server_json:
                 theme_info_model.update_table('server_json=%s', 'out_id=%s', params=[server_json, out_id])
         else:
@@ -194,9 +192,9 @@ class ThemeBaseModel():
                 return invoke_result_data
             theme_info = ThemeInfo()
             theme_info.theme_name = theme_name
-            theme_info.client_json = client_json
             theme_info.server_json = server_json
             theme_info.out_id = out_id
+            theme_info.style_type = style_type
             if app_id != "":
                 theme_info.app_id = app_id
                 theme_info.is_private = 1
@@ -204,7 +202,7 @@ class ThemeBaseModel():
             theme_info.is_release = 1
             theme_info.create_date = SevenHelper.get_now_datetime()
             theme_id = theme_info_model.add_entity(theme_info)
-            if ver_no:
+            if theme_id:
                 theme_ver = ThemeVer()
                 theme_ver.app_id = theme_info.app_id
                 theme_ver.out_id = out_id
