@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-08-12 09:06:24
-@LastEditTime: 2021-09-06 19:40:28
+@LastEditTime: 2021-11-01 13:33:56
 @LastEditors: HuangJianYi
 :description: 淘宝top接口基础类
 """
@@ -303,7 +303,7 @@ class TopBaseModel():
                         return invoke_result_data
             return invoke_result_data
 
-    def get_buy_order_list(self, open_id, access_token,app_key, app_secret, start_created="", end_created="", page_size=50, is_log=False):
+    def get_buy_order_list(self, open_id, access_token, app_key, app_secret, start_created="", end_created="", page_size=50, is_log=False, type="fixed,step"):
         """
         :description: 获取淘宝购买订单
         :param open_id：open_id
@@ -314,6 +314,7 @@ class TopBaseModel():
         :param end_created：结束时间
         :param page_size：页大小
         :param is_log：是否记录返回信息
+        :param type：订单类型
         :return InvokeResultData
         :last_editors: HuangJianYi
         """
@@ -323,8 +324,8 @@ class TopBaseModel():
         try:
             top.setDefaultAppInfo(app_key, app_secret)
             req = top.api.OpenTradesSoldGetRequest()
-            req.fields = "tid,status,payment,price,created,orders,num,pay_time"
-            req.type = "fixed"
+            req.fields = "tid,status,payment,price,created,orders,num,pay_time,step_trade_status,step_paid_fee,type"
+            req.type = type
             req.buyer_open_id = open_id
             req.page_size = page_size
             req.page_no = 1
