@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-22 11:10:20
-@LastEditTime: 2021-11-02 18:49:52
+@LastEditTime: 2021-11-26 17:50:47
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -233,6 +233,8 @@ class UserBaseModel(FrameBaseModel):
                     return invoke_result_data
                 user_info.user_nick = user_account.user_nick
                 user_info.avatar = user_account.avatar
+                # if TimeHelper.difference_minutes(now_datetime,user_info.create_date) > 1:
+                #     user_info.is_new = 0
                 user_info.is_new = 0
                 user_info.modify_date = now_datetime
                 user_info.login_token = SevenHelper.get_random(16)
@@ -306,7 +308,8 @@ class UserBaseModel(FrameBaseModel):
                     update_sql += "avatar=%s"
                     params.append(avatar)
                 params.append(user_info_dict["user_id"])
-                user_account_model.update_table(update_sql, "id=%s", params=params)
+                if update_sql:
+                    user_account_model.update_table(update_sql, "id=%s", params=params)
 
         except Exception as ex:
             self.context.logging_link_error("【更新用户信息】" + traceback.format_exc())
