@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-04-16 14:38:22
-@LastEditTime: 2021-11-02 18:56:50
+@LastEditTime: 2021-11-26 13:59:49
 @LastEditors: HuangJianYi
 :Description: 基础路由   业务方可以直接使用语句 handlers.extend(seven_cloudapp_frame.route.seven_cloudapp_frame_route()) 引入
 """
@@ -37,6 +37,7 @@ def seven_cloudapp_frame_route():
         (r"/client/ip_info_list", ip.IpInfoListHandler),  #ip信息列表
         (r"/client/act_info", act.ActInfoHandler),  #活动信息
         (r"/client/act_prize_list", act.ActPrizeListHandler),  #活动奖品列表
+        (r"/client/cms_info_list", act.CmsInfoListHandler),  #位置信息列表
         (r"/client/app_expire", app.AppExpireHandler),  #小程序过期时间
         (r"/client/sku_info", goods.SkuInfoHandler),  #sku信息
         (r"/client/goods_list", goods.GoodsListHandler),  #商品列表
@@ -72,9 +73,10 @@ def seven_cloudapp_frame_route():
         (r"/server/saas_custom", base_s.SaasCustomHandler),  #saas定制化信息获取
         (r"/server/login", user_s.LoginHandler),  #千牛端登录
         (r"/server/left_navigation", base_s.LeftNavigationHandler),  #左侧导航
-        (r"/server/right_navigation", base_s.RightExplainHandler),  #右侧各种教程和说明导航
-        (r"/server/friend_link_list", base_s.FriendLinkListHandler),  #获取友情链接列表
+        (r"/server/friend_link_list", base_s.FriendLinkListHandler),  #获取友情链接产品互推列表
         (r"/server/send_sms", base_s.SendSmsHandler),  #发短信
+        (r"/server/cms_info_list", base_s.CmsInfoListHandler),  #位置信息列表
+        (r"/server/save_cms_info_", base_s.SaveCmsInfoHandler),  #保存位置信息
         (r"/server/app_info", app_s.AppInfoHandler),  #应用信息
         (r"/server/get_app_id", app_s.GetAppIDHandler),  #根据店铺名称返回应用标识 用于GM工具
         (r"/server/instantiate", app_s.InstantiateAppHandler),  #实例化小程序
